@@ -2,7 +2,7 @@ package Test::Ika;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Module::Load;
 use Test::Name::FromLine;
@@ -14,6 +14,7 @@ use parent qw/Exporter/;
 
 our @EXPORT = (qw(
     describe it context
+    xit
     before_suite after_suite
     before_all after_all before_each after_each
     runtests
@@ -68,6 +69,12 @@ sub it {
     $CURRENT->add_example($it);
 }
 
+sub xit {
+    my ($name, $code) = @_;
+    my $it = Test::Ika::Example->new(name => $name, code => $code, skip => 1);
+    $CURRENT->add_example($it);
+}
+
 sub before_suite(&) {
     my $code = shift;
     $ROOT->add_trigger(before_all => $code);
@@ -212,6 +219,10 @@ It's alias of 'describe' function.
 
 Create new L<Test::Ika::Example>.
 
+=item xit($name, $code)
+
+Create new L<Test::Ika::Example> which marked "disabled".
+
 =item before_suite(\&code)
 
 Register hook.
